@@ -43,6 +43,8 @@ type CreateOpts struct {
 	ReleasedAt       string
 	RepoOverride     string
 	PublishToCatalog bool
+	NoUpdate         bool
+	NoCloseMilestone bool
 
 	NoteProvided       bool
 	ReleaseNotesAction string
@@ -79,12 +81,12 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 
 		To fetch the new tag locally after the release, run %[1]sgit fetch --tags origin%[1]s.
 		`, "`"),
-		Args: cmdutils.MinimumArgs(1, "no tag name provided"),
+		Args: cmdutils.MinimumArgs(1, "no tag name provided."),
 		Example: heredoc.Docf(`
-			# Interactively create a release
+			# Create a release interactively
 			$ glab release create v1.0.1
 
-			# Non-interactively create a release by specifying a note
+			# Create a release non-interactively by specifying a note
 			$ glab release create v1.0.1 --notes "bugfix release"
 
 			# Use release notes from a file
@@ -96,10 +98,10 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			# Upload a release asset with a display name and type
 			$ glab release create v1.0.1 '/path/to/asset.png#My display label#image'
 
-			# Upload all assets in a specified folder (types will default to 'other')
+			# Upload all assets in a specified folder (types default to 'other')
 			$ glab release create v1.0.1 ./dist/*
 
-			# Upload all tarballs in a specified folder (types will default to 'other')
+			# Upload all tarballs in a specified folder (types default to 'other')
 			$ glab release create v1.0.1 ./dist/*.tar.gz
 
 			# Create a release with assets specified as JSON object
@@ -114,19 +116,23 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			  ]'
 
 			# [EXPERIMENTAL] Create a release and publish it to the GitLab CI/CD catalog
-			# This command should NOT be run manually, but rather as part of a CI/CD pipeline with the "release" keyword.
-			# The API endpoint accepts only "CI_JOB_TOKEN" as the authentication token.
-			# This command retrieves components from the current repository by searching for %[1]syml%[1]s files
-			# within the "templates" directory and its subdirectories.
-			# This flag will not work if the feature flag %[1]sci_release_cli_catalog_publish_option%[1]s is not enabled
-			# for the project in the GitLab instance.
+			# Requires the feature flag %[1]sci_release_cli_catalog_publish_option%[1]s to be enabled
+			# for this project in your GitLab instance. Do NOT run this manually. Use it as part
+			# of a CI/CD pipeline with the "release" keyword:
+			#
+			# - The API endpoint accepts only "CI_JOB_TOKEN" as the authentication token.
+			# - It retrieves components from the current repository by searching for
+			#   %[1]syml%[1]s files within the "templates" directory and its subdirectories.
+			# - It fails if the feature flag %[1]sci_release_cli_catalog_publish_option%[1]s
+			#   is not enabled for this project in your GitLab instance.
 
-			# Components can be defined;
+			# Components can be defined:
 
 			# - In single files ending in %[1]s.yml%[1]s for each component, like %[1]stemplates/secret-detection.yml%[1]s.
-			# - In sub-directories containing %[1]stemplate.yml%[1]s files as entry points,
-			# 	for components that bundle together multiple related files. For example,
-			# 	%[1]stemplates/secret-detection/template.yml%[1]s.
+			# - In subdirectories containing %[1]stemplate.yml%[1]s files as entry points,
+			#   for components that bundle together multiple related files. For example,
+			#   %[1]stemplates/secret-detection/template.yml%[1]s.
+
 			$ glab release create v1.0.1 --publish-to-catalog
 `, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -181,6 +187,8 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	cmd.Flags().StringSliceVarP(&opts.Milestone, "milestone", "m", []string{}, "The title of each milestone the release is associated with.")
 	cmd.Flags().StringVarP(&opts.AssetLinksAsJson, "assets-links", "a", "", "'JSON' string representation of assets links, like `--assets-links='[{\"name\": \"Asset1\", \"url\":\"https://<domain>/some/location/1\", \"link_type\": \"other\", \"direct_asset_path\": \"path/to/file\"}]'.`")
 	cmd.Flags().BoolVar(&opts.PublishToCatalog, "publish-to-catalog", false, "[EXPERIMENTAL] Publish the release to the GitLab CI/CD catalog.")
+	cmd.Flags().BoolVar(&opts.NoUpdate, "no-update", false, "Prevent updating the existing release.")
+	cmd.Flags().BoolVar(&opts.NoCloseMilestone, "no-close-milestone", false, "Prevent closing milestones after creating the release.")
 
 	return cmd
 }
@@ -368,6 +376,10 @@ func createRun(opts *CreateOpts) error {
 		opts.IO.Logf("%s Release created:\t%s=%s\n", color.GreenCheck(),
 			color.Blue("url"), release.Links.Self)
 	} else {
+		if opts.NoUpdate {
+			return releaseFailedErr(fmt.Errorf("release for tag %q already exists and --no-update flag was specified", opts.TagName), start)
+		}
+
 		updateOpts := &gitlab.UpdateReleaseOptions{
 			Name: &opts.Name,
 		}
@@ -398,28 +410,29 @@ func createRun(opts *CreateOpts) error {
 		return releaseFailedErr(err, start)
 	}
 
-	if len(opts.Milestone) > 0 {
-		// close all associated milestones
-		for _, milestone := range opts.Milestone {
-			// run loading msg
-			opts.IO.StartSpinner("Closing milestone %q", milestone)
-			// close milestone
-			err := closeMilestone(opts, milestone)
-			// stop loading
-			opts.IO.StopSpinner("")
-			if err != nil {
-				opts.IO.Log(color.FailedIcon(), err.Error())
-			} else {
-				opts.IO.Logf("%s Closed milestone %q\n", color.GreenCheck(), milestone)
+	if opts.NoCloseMilestone {
+		opts.IO.Logf("%s Skipping closing milestones\n", color.GreenCheck())
+	} else {
+		if len(opts.Milestone) > 0 {
+			// close all associated milestones
+			for _, milestone := range opts.Milestone {
+				opts.IO.StartSpinner("Closing milestone %q", milestone)
+				err := closeMilestone(opts, milestone)
+				opts.IO.StopSpinner("")
+				if err != nil {
+					opts.IO.Log(color.FailedIcon(), err.Error())
+				} else {
+					opts.IO.Logf("%s Closed milestone %q\n", color.GreenCheck(), milestone)
+				}
 			}
 		}
 	}
-	opts.IO.Logf(color.Bold("%s Release succeeded after %0.2fs.\n"), color.GreenCheck(), time.Since(start).Seconds())
+	opts.IO.Logf(color.Bold("%s Release succeeded after %0.2f seconds.\n"), color.GreenCheck(), time.Since(start).Seconds())
 
 	if opts.PublishToCatalog {
 		err = catalog.Publish(opts.IO, client, repo.FullName(), release.TagName)
 		if err != nil {
-			return cmdutils.WrapError(err, "failed to publish the release to the GitLab CI/CD catalog")
+			return cmdutils.WrapError(err, "failed to publish the release to the GitLab CI/CD catalog.")
 		}
 	}
 
@@ -427,7 +440,7 @@ func createRun(opts *CreateOpts) error {
 }
 
 func releaseFailedErr(err error, start time.Time) error {
-	return cmdutils.WrapError(err, fmt.Sprintf("release failed after %0.2fs.", time.Since(start).Seconds()))
+	return cmdutils.WrapError(err, fmt.Sprintf("release failed after %0.2f seconds.", time.Since(start).Seconds()))
 }
 
 func getMilestoneByTitle(c *CreateOpts, title string) (*gitlab.Milestone, error) {
